@@ -2,21 +2,7 @@
 
 set -e -x -u
 
-APT_UPDATED=false
-
-function ensure-apt-update {
-  if [[ $APT_UPDATED != "false" ]] ; then
-    return
-  fi
-
-  apt-get update
-  APT_UPDATED=true
-}
-
-if [[ ${TEST_WITH_APT_REPO_RUBY:-} != "" ]] ; then
-  ensure-apt-update
-  apt-get install -y ruby ruby-dev bundler libxslt-dev libxml2-dev pkg-config
-fi
+source "$(dirname "$0")/../../shared/code-climate.sh"
 
 VERSION_INFO=$(ruby -v)
 RUBY_ENGINE=$(cut -d" " -f1 <<< "${VERSION_INFO}")
@@ -43,28 +29,11 @@ function commit-is-post-frozen-string-support {
   return 1
 }
 
-function rbx-engine {
-  if [[ $RUBY_ENGINE == "rubinius" ]] ; then
-    return 0
-  fi
-  return 1
-}
-
 pushd nokogiri
 
-  RAKE_TASK="test"
+  test_task="test"
 
-  if rbx-engine ; then
-    ensure-apt-update
-    apt-get install -y ca-certificates gcc pkg-config libxml2-dev libxslt-dev patch
-  fi
-
-  if [[ ${TEST_WITH_VALGRIND:-} != "" ]] ; then
-    ensure-apt-update
-    apt-get install -y valgrind
-  fi
-
-  bundle install
+  bundle install --local || bundle install
   bundle exec rake generate # do this before setting frozen string option, because racc isn't compatible with frozen string literals yet
 
   if mri-24-or-greater && commit-is-post-frozen-string-support ; then
@@ -72,8 +41,8 @@ pushd nokogiri
   fi
 
   if [[ ${TEST_WITH_VALGRIND:-} != "" ]] ; then
-    RAKE_TASK="test:valgrind" # override
-    export TESTOPTS="-v" # see more verbose output to help narrow down warnings
+    test_task="test:valgrind" # override
+    # export TESTOPTS="-v" # see more verbose output to help narrow down warnings
 
     # always use the CI suppressions if they exist
     if [[ -d ../ci/suppressions ]] ; then
@@ -82,6 +51,10 @@ pushd nokogiri
     fi
   fi
 
-  bundle exec rake ${RAKE_TASK}
+  code-climate-setup
+
+  bundle exec rake compile ${test_task}
+
+  code-climate-shipit
 
 popd
